/*
 * Plugin Name: popup
 *
 * Author: Dominik Gruber
 * URL: https://creo-code.at
 * v 1.0.0
 *
 */
 
(function($) {
  $.fn.popup = function(opts) {

    var $windows = $(window),
        $html = $('html'),
        $body = $('body');

    var defaults = {
      elementID: '', // ID of Element
      appearance: 'onPageLoad', // onPageLoad OR onScroll
      delay: '1000', // numeric value
      scrollOffset: '1000', // numeric value
      animationIn: 'fadeIn', // css class for animation in effect
      animationInSpeed: '1000', // numeric value
      animationOut: 'fadeOut', // css class for animation in effect
      animationOutSpeed: '1000', // numeric value
      darkenPage: 1, // 1 == true / 0 == false
      darkenAnimationIn: 'fadeIn', // css class for animation in effect
      darkenAnimationInSpeed: '1000', // numeric value
      darkenAnimationOut: 'fadeOut', // css class for animation in effect
      darkenAnimationOutSpeed: '1000', // numeric value
      darkenerClickToClose: false, // 1 == true / 0 == false
      cookieExpire: '7' // numeric value
    }

    var opts = $.extend(defaults, opts);
    var popupTriggered = false;

    // Show Popup
    function showPopup(obj) {
      setTimeout(function() {
        obj.show();
        objInside.css({'animation-duration': opts.animationInSpeed+'ms'});
        objInside.addClass('animated ' + opts.animationIn);
        $html.addClass('popup-active');

        // darken page
        if (opts.darkenPage === 1) {
          var darkener = $('#'+opts.elementID+'-darkener');
          darkener.show();
          darkener.css({'animation-duration': opts.darkenAnimationInSpeed+'ms'});
          darkener.addClass('animated ' + opts.darkenAnimationIn);
          // remove class and css
          setTimeout(function() {
            darkener.css({'animation-duration': ''});
            darkener.removeClass('animated ' + opts.darkenAnimationIn);
          }, opts.animationInSpeed);
        }

        // remove class and css
        setTimeout(function() {
          objInside.css({'animation-duration': ''});
          objInside.removeClass('animated ' + opts.animationIn);
        }, opts.animationInSpeed);
      }, opts.delay);
    }

    // Hide Popup
    function hidePopup(obj) {
      objInside.css({'animation-duration': opts.animationOutSpeed+'ms'});
      objInside.addClass('animated ' + opts.animationOut);

      // darken page
      if (opts.darkenPage === 1) {
        var darkener = $('#'+opts.elementID+'-darkener');
        darkener.css({'animation-duration': opts.darkenAnimationOutSpeed+'ms'});
        darkener.addClass('animated ' + opts.darkenAnimationOut);
        // remove class and css
        setTimeout(function() {
          darkener.hide();
          darkener.css({'animation-duration': ''});
          darkener.removeClass('animated ' + opts.darkenAnimationOut);
        }, opts.darkenAnimationOutSpeed);
      }

      // remove class and css
      setTimeout(function() {
        obj.hide();
        $html.removeClass('popup-active');
      }, opts.animationOutSpeed);
    }

    var obj = $('#'+opts.elementID),
        objInside = obj.find('> .inside'),
        objCloser = obj.find('.closer');

    // Control appearance
    var popupCookie = getCookie(opts.elementID);
    if (popupCookie != '1') {
      if (opts.appearance == "onPageLoad") {
        showPopup(obj);
      } else if (opts.appearance == "onScroll") {
        $windows.bind("scroll.alert", function() {
            var $this = $(this);
            if ($this.scrollTop() >= opts.scrollOffset) {
                showPopup(obj);
                $this.unbind("scroll.alert");
            }
        });
      }
    }

    // Closer
    objCloser.click(function() {
      // hide popup
      hidePopup(obj);
      // set cookie
      setCookie(opts.elementID, "1", opts.cookieExpire);
    });

    // darkenerClickToClose
    if (opts.darkenPage === 1 && opts.darkenerClickToClose === 1) {
      var darkener = $('#'+opts.elementID+'-darkener');
      darkener.click(function() {
        // hide popup
        hidePopup(obj);
        // set cookie
        setCookie(opts.elementID, "1", opts.cookieExpire);
      });
    }

    function getCookie(cname) {
        var name = cname + "=";
        var ca = document.cookie.split(';');
        for(var i = 0; i < ca.length; i++) {
            var c = ca[i];
            while (c.charAt(0) == ' ') {
                c = c.substring(1);
            }
            if (c.indexOf(name) == 0) {
                return c.substring(name.length, c.length);
            }
        }
        return "";
    }
    function setCookie(cname, cvalue, exdays) {
        var d = new Date();
        d.setTime(d.getTime() + (exdays * 24 * 60 * 60 * 1000));
        var expires = "expires="+d.toUTCString();
        document.cookie = cname + "=" + cvalue + ";" + expires + ";path=/";
    }

    
  }
})(jQuery);